# file-tools

common file conversions

## Installation

```BASH
pip install file-convertion-tools
```

## Usage example

Importing

```Python
import file_tools
```

Usage

```Python
```

<!--
## Create a new release

example:

```BASH
git tag 0.0.1
git push origin --tags
```

release a patch:

```BASH
poetry version patch
```

then `git commit`, `git push` and

```BASH
git tag 0.0.2
git push origin --tags
```
-->
